#include <SoftwareSerial.h>
#include <CompactQik2s9v1.h>

#define xbeeRx    A0           // DOUT to A0
#define xbeeTx    A1           // DIN to A1
#define rxPin     5            // Qik motor Rx
#define txPin     6            // Qik motor Tx
#define rstPin    7            // Qik motor reset

byte topSpeed = 96;

SoftwareSerial motorSerial (rxPin, txPin);
CompactQik2s9v1 motor = CompactQik2s9v1(&motorSerial, rstPin);
SoftwareSerial Xbee (xbeeRx, xbeeTx);    //After motor serial

boolean motorsOn = false;

void setup() {
  Serial.begin(9600);
  motorSerial.begin(9600);
  motor.begin();
  motor.stopBothMotors();
  Xbee.begin(9600);          // Place last
  delay(200);
  pinMode(13, OUTPUT);       // Show ready status
  digitalWrite(13, HIGH);
}

void loop() {
  readXbee();
  delay(50);
}

void readXbee() {
   if(Xbee.available()) { 
     char val = Xbee.read();
     Serial.println(val);
     controlMotor(val);
  }
}

void controlMotor(char val) {
  switch (val) {
    case ('c'):
      motorsStop();
      break;
    case ('u'):
      motorsForward(topSpeed);
      break;
    case ('d'):
      motorsReverse(topSpeed);
      break;
    case ('r'):
      motorsTurnRight(topSpeed);
      break;
    case ('l'):
      motorsTurnLeft(topSpeed);
      break;
  }
}

//  motor0 = left, motor1 = right
void motorsStop() {
  motor.motor0Forward(0);
  motor.motor1Forward(0);
}
void motorsForward(byte motorSpeed) {
  motor.motor0Forward(motorSpeed);
  motor.motor1Forward(motorSpeed);
}
void motorsReverse(byte motorSpeed) {
  motor.motor0Reverse(motorSpeed);
  motor.motor1Reverse(motorSpeed);
}
void motorsSpinRight(byte motorSpeed) {
  motor.motor0Forward(motorSpeed);
  motor.motor1Reverse(motorSpeed);
}
void motorsSpinLeft(byte motorSpeed) {
  motor.motor0Reverse(motorSpeed);
  motor.motor1Forward(motorSpeed);
}
void motorsTurnRight(byte motorSpeed) {
  motor.motor0Forward(motorSpeed);
  motor.motor1Forward(0);
}
void motorsTurnLeft(byte motorSpeed) {
  motor.motor0Forward(0);
  motor.motor1Forward(motorSpeed);
}
